import { useAjax } from '@/Hook/useAjax';
import {
  apiLongBookConfirmUploadLongBook,
  apiLongBookUploadLongBook,
} from '@/services/book/longbookList';
import { apiShortBookUploadShortBook } from '@/services/book/shortbookList';
import { InboxOutlined, MinusCircleOutlined } from '@ant-design/icons';
import {
  Button,
  Card,
  Col,
  Form,
  FormProps,
  Input,
  message,
  Radio,
  Row,
  Space,
  Typography,
  UploadProps,
} from 'antd';
import { RcFile } from 'antd/es/upload';
import Dragger from 'antd/es/upload/Dragger';
import React, { useCallback, useMemo, useState } from 'react';
const { Title } = Typography;

function UploadFile(props: {
  type: 'long' | 'short';
  open: boolean;
  bookId: string;
  refresh?: () => void;
}) {
  let { type, bookId, refresh, open } = props;
  let [file, setFile] = useState<RcFile | null>(null); //上传文件
  let [longUpdata, setLongUpData] = useState<any>(null); //长篇小说上传后的结果
  let [uploadType, setUploadType] = useState<any>(2); //新传或续传
  const [form] = Form.useForm(); //新增修改小说form表单实例
  let ShortBookUploadShortBook = useAjax((params) => apiShortBookUploadShortBook(params)); //短篇小说上传
  let LongBookUploadLongBook = useAjax((params) => apiLongBookUploadLongBook(params)); //长篇小说上传
  let LongBookConfirmUploadLongBook = useAjax((params) => apiLongBookConfirmUploadLongBook(params)); //长篇小说确认

  let config: any = useMemo(() => {
    let config = {};
    if (!open) {
      //关闭段落编辑时清空
      setFile(null);
      setLongUpData(null);
    }
    if (type === 'long') {
      config = {
        name: '长篇小说',
        bookId,
        api: LongBookUploadLongBook,
        refresh,
      };
    } else {
      config = {
        name: '短篇小说',
        bookId,
        api: ShortBookUploadShortBook,
        refresh,
      };
    }
    return config;
  }, [type, bookId, refresh, open]);
  const uploadProprs: UploadProps = {
    name: 'file',
    multiple: false,
    action: '#',
    accept: '.txt',
    fileList: file ? [file] : [],
    // disabled: type === 'short' ? false : !!file,
    beforeUpload: (file: RcFile) => {
      submit(file);
    },
    customRequest: () => {},
  };
  const submit = useCallback(
    (file: RcFile) => {
      let formData = new FormData();
      let data: any = { file, bookId: config.bookId };
      // 短篇小说加入uploadType
      if (config.name === '短篇小说') {
        data.uploadType = uploadType;
      }
      Object.keys(data).forEach((key: string) => {
        formData.append(key, data[key]);
      });
      config.api.run(formData).then((res: any) => {
        if (res.code === 200) {
          message.success('上传成功！');
          // 短篇小说刷新页面
          if (config.name === '短篇小说') {
            config.refresh();
          } else {
            // 长篇小说存放数据
            setLongUpData(res.data);
            form.setFieldsValue({ chapters: res.data.chapters });
          }
          setFile(file);
        }
      });
      console.log(config, file);
    },
    [config, uploadType, form],
  );
  // 表单错误
  const onFinishFailed: FormProps['onFinishFailed'] = (errorInfo) => {
    console.log('Failed:', errorInfo);
  };
  // 删除
  const handleRemove = (name: any) => {
    const chapters: any = form.getFieldValue('chapters');
    const newChapters = chapters.map((chapter: any, index: any) => {
      if (index === name) {
        return { ...chapter, status: 1 }; // 设置status为1
      }
      return chapter;
    });
    console.log(chapters, newChapters);
    form.setFieldsValue({ chapters: newChapters });
  };
  const longSubmit: FormProps['onFinish'] = (values) => {
    console.log(values);
    LongBookConfirmUploadLongBook.run({
      ...values,
      uploadType,
      bookId,
      fileUrl: longUpdata.fileUrl,
    }).then((res) => {
      if (res.code === 200) {
        refresh?.();
        setFile(null);
        setLongUpData(null);
      }
    });
  };
  return (
    <div>
      <Card>
        <Title style={{ marginTop: 0, textAlign: 'center' }}>{config?.name}上传</Title>
        <Space direction="vertical" style={{ width: '100%' }}>
          <Radio.Group
            onChange={(e) => {
              setUploadType(e.target.value);
            }}
            value={uploadType}
          >
            <Radio value={1}>新传小说</Radio>
            <Radio value={2}>续传小说</Radio>
          </Radio.Group>
          <Dragger {...uploadProprs}>
            <p className="ant-upload-drag-icon">
              <InboxOutlined />
            </p>
            <p className="ant-upload-text">{config?.name}上传</p>
            <p className="ant-upload-hint">点击或拖动文件至此处</p>
            <p className="ant-upload-hint" color="#000">
              当前为<span style={{ color: 'red' }}>{uploadType == 2 ? '续传' : '新传'}</span>
              模式，会<span style={{ color: 'red' }}>{uploadType == 2 ? '保留' : '清除'}</span>
              已有小说内容
            </p>
          </Dragger>
          {
            //
            type === 'long' && longUpdata && (
              <Row justify={'center'} style={{ marginTop: 20 }}>
                <Col>
                  <Form
                    name="basic"
                    labelCol={{ span: 5 }}
                    wrapperCol={{ span: 16 }}
                    style={{ minWidth: 600 }}
                    onFinish={longSubmit}
                    onFinishFailed={onFinishFailed}
                    autoComplete="off"
                    form={form}
                  >
                    <Form.List name="chapters">
                      {(fields, { add, remove }) => {
                        return (
                          <>
                            {fields.map(({ key, name, ...restField }, index) => {
                              let status = form.getFieldValue(['chapters', name, 'status']);
                              console.log(status);
                              return (
                                <React.Fragment key={key}>
                                  <Form.Item
                                    label={`章节标题`}
                                    style={{ position: 'relative' }}
                                    hidden={status === 1}
                                  >
                                    <Form.Item
                                      {...restField}
                                      name={[name, 'chapterTitle']}
                                      rules={[{ required: true, message: '请补充标题' }]}
                                      wrapperCol={{ span: 22 }}
                                      style={{ marginBottom: 0 }}
                                    >
                                      <Input placeholder="请输入标题" />
                                    </Form.Item>
                                    <MinusCircleOutlined
                                      onClick={() => {
                                        handleRemove(name);
                                      }}
                                      style={{
                                        position: 'absolute',
                                        top: '50%',
                                        right: 0,
                                        transform: 'translateY(-50%)',
                                      }}
                                    />
                                  </Form.Item>
                                </React.Fragment>
                              );
                            })}
                          </>
                        );
                      }}
                    </Form.List>
                    <Form.Item wrapperCol={{ offset: 0, span: 24 }}>
                      <div style={{ display: 'flex', justifyContent: 'center' }}>
                        <Button
                          type="primary"
                          htmlType="submit"
                          loading={LongBookConfirmUploadLongBook.loading}
                        >
                          确认并提交
                        </Button>
                      </div>
                    </Form.Item>
                  </Form>
                </Col>
              </Row>
            )
          }
        </Space>
      </Card>
    </div>
  );
}

export default UploadFile;
