import { apibookAuthorListAll } from '@/services/book/author';
import { apiBookContentLabelListAll } from '@/services/book/bookTags';
import { apibookCategoryListAll } from '@/services/book/classifyList';
import { enumDictList } from '@/services/global';
import { Badge } from 'antd';
import { useReducer } from 'react';

type State = {
  enumList?: { [key: string]: any[] }; //枚举
  labelList?: any[]; //标签列表
  categoryList?: any[]; //分类列表
  authList?: any[]; //作者列表
};
type Action = {
  params?: any;
  type: 'setEnum' | 'setLabelList' | 'setCategoryList' | 'setAuthList' | 'setAll';
};
export function reducer(state: State, action: Action) {
  let { type, params } = action;
  switch (type) {
    case 'setEnum':
      return { ...state, enumList: params?.enumList };
    case 'setLabelList':
      return { ...state, labelList: params?.labelList };
    case 'setCategoryList':
      return { ...state, categoryList: params?.categoryList };
    case 'setAuthList':
      return { ...state, authList: params?.authList };
    case 'setAll':
      return { ...state, ...params };
    default:
      return state;
  }
}
export default (): {
  state: State;
  init: () => void;
  getEnum: (enumName: string, type: "map" | "arr" | "obj" | "stateObj", stateEnum?: any) => any;
  getLabelAndClassList: (params?: { workDirection: number | string }) => Promise<boolean>;
} => {
  const [state, dispatch] = useReducer(reducer, {});
  let isLoding = false;
  const init = async () => {
    if (isLoding) {
      return;
    }
    console.log('初始化');
    isLoding = true;
    let enumData: any = await enumDictList()
      .then((res) => res.data)
      .catch((err) => {
        console.log(err);
      });
    let authList = await apibookAuthorListAll()
      .then((res) => res.data)
      .catch((err) => {
        console.log(err);
      });
    let enumList: { [key: string]: any } = {};
    if (enumData) {
      Object.values(enumData.enums).map((item: any) => {
        enumList[item.name] = item;
      });
    }
    // 收费货币
    if (enumList && !enumList.PAYMENT_CATEGORY) {
      enumList.PAYMENT_CATEGORY = {};
      enumList.PAYMENT_CATEGORY.values = [
        { value: 0, description: '现金' },
        { value: 1, description: '书币' },
      ];
    }
    //是否开放给所有分销商
    if (enumList && !enumList?.PUBLIC_DISTRIBUTOR) {
      enumList.PUBLIC_DISTRIBUTOR = {};
      enumList.PUBLIC_DISTRIBUTOR.values = [
        { value: false, description: '否' },
        { value: true, description: '是' },
      ];
    }
    // 是否允许分销商配置价格
    if (enumList && !enumList?.ALLOW_DISTRIBUTOR_CONFIG) {
      enumList.ALLOW_DISTRIBUTOR_CONFIG = {};
      enumList.ALLOW_DISTRIBUTOR_CONFIG.values = [
        { value: false, description: '否' },
        { value: true, description: '是' },
      ];
    }
    dispatch({ type: 'setAll', params: { enumList, authList } });
    isLoding = false;
  };
  const getLabelAndClassList = async (params?: { workDirection: number | string }) => {
    let labelList = null;
    let categoryList = null;
    if (typeof params?.workDirection === 'number') {
      labelList = await apiBookContentLabelListAll(params)
        .then((res) => res.data)
        .catch((err) => {
          console.log(err);
        });
      categoryList = await apibookCategoryListAll(params)
        .then((res) => res.data)
        .catch((err) => {
          console.log(err);
        });
    }
    dispatch({ type: 'setAll', params: { ...state, labelList, categoryList } });
    return true;
  };
  /**
   * @param enumName 枚举名称
   * @param type 类型 "map" 通用在列表中选中值输出值会变成number | "arr" 数组类型返回 | "obj" 对象类型返回 再列表中选中输出值为string | "stateObj" 带状态徽标返回的对象
   * @param stateEnum 类型  "stateObj" 时传入映射对象 {success?:number,error?:number,default?:number,processing?:number,warning:number} number为对应值展示什么状态
   * */
  const getEnum = (enumName: string, type: "map" | "arr" | "obj" | "stateObj", stateEnum?: any) => {
    let arr = state?.enumList?.[enumName]?.values
    // console.log("arr",enumName,arr)
    switch (type) {
      case "map":
        return new Map(arr?.map(({ value, description }: any) => [value, description]))
      case "arr":
        return arr?.map(({ value, description }: any) => ({ value, key: value, label: description, disabled: false }))
      case "obj":
        let obj: any = {}
        if (arr) {
          for (let item of arr) {
            obj[item?.value] = { text: item?.description, disabled: false }
          }
        }
        return obj
      case "stateObj":
        let stateObj: any = {}
        if (arr && stateEnum) {
          for (let item of arr) {
            stateObj[item?.value] = { text: <Badge status={stateEnum[item?.value]} text={item.description} />, disabled: false }
          }
        }
        return stateObj
    }
  }
  return {
    state,
    init,
    getEnum,
    getLabelAndClassList,
  };
};
