import { useAjax } from '@/Hook/useAjax';
import {
  apiBookContentLabelAdd,
  apiBookContentLabelDel,
  apiBookContentLabelEdit,
  apiBookContentLabelHot,
  apiBookContentLabelList,
  apiBookContentLabelSort,
} from '@/services/book/bookTags';
import { PlusCircleOutlined } from '@ant-design/icons';
import {
  ActionType,
  BetaSchemaForm,
  PageContainer,
  ProFormInstance,
} from '@ant-design/pro-components';
import { useModel } from '@umijs/max';
import { Button, message } from 'antd';
import { useRef, useState } from 'react';
import formConfig from './formConfig';
import { columns } from './tableConfig';
import MyProTable from '@/components/MyProTable';

type DataItem = {
  name: string;
  state: string;
};
const Page: React.FC = () => {
  const formRef = useRef<ProFormInstance>();
  const actionRef = useRef<ActionType>();
  let { state } = useModel('global');
  let [open, setOpen] = useState<any>(null); //新增作者
  let [editValues, setEditValues] = useState<any>({});
  let BookContentLabelList = useAjax((params) => apiBookContentLabelList(params), {
    type: 'table',
  });
  let BookContentLabelEdit = useAjax((params) => apiBookContentLabelEdit(params));
  let BookContentLabelAdd = useAjax((params) => apiBookContentLabelAdd(params));
  let BookContentLabelDel = useAjax((params) => apiBookContentLabelDel(params));
  let BookContentLabelHot = useAjax((params) => apiBookContentLabelHot(params));
  let BookContentLabelSort = useAjax((params) => apiBookContentLabelSort(params));
  // 编辑
  const edit = (item: any) => {
    setEditValues(item);
    setTimeout(() => {
      formRef?.current?.setFieldsValue({ ...item });
    }, 100);
    setOpen(true);
  };
  // 删除
  const del = (id: any) => {
    BookContentLabelDel.run(id).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('删除成功');
      }
    });
  };
  // 新增 or 编辑
  const submit = async (values: any) => {
    let api = editValues?.id ? BookContentLabelEdit : BookContentLabelAdd;
    if (editValues?.id) {
      values.id = editValues?.id;
    }
    api.run(values).then((res) => {
      if (res.code === 200) {
        actionRef?.current?.reload();
        message.success('操作成功!');
        closeForm(false);
      }
    });
    console.log(values);
  };
  // 关闭表单弹窗和重置表单内容
  const closeForm = (b: boolean, values?: any) => {
    if (!b) {
      setEditValues({});
      formRef?.current?.resetFields?.();
      setOpen(b);
    } else {
    }
  };
  //热门
  const hot = (params: any) => {
    return BookContentLabelHot.run(params)
      .then((res: any) => {
        if (!res?.code) {
          return false;
        } else {
          actionRef?.current?.reload();
          message.success('修改热门状态成功');
          return true;
        }
      })
      .catch((err: any) => {
        return false;
      });
  };
  // 排序
  const sort = (params: any) => {
    return BookContentLabelSort.run(params)
      .then((res: any) => {
        if (!res?.code) {
          return false;
        } else {
          actionRef?.current?.reload();
          message.success('修改排序成功');
          return true;
        }
      })
      .catch((err: any) => {
        return false;
      });
  };
  return (
    <PageContainer>
      <MyProTable<any, any>
        headerTitle={'标签列表'}
        actionRef={actionRef}
        rowKey={(r) => r.id}
        search={{
          labelWidth: 120,
        }}
        request={async (params) => {
          return await BookContentLabelList.run(params);
        }}
        scroll={{ x: 'max-content' }}
        toolBarRender={() => {
          return [
            <Button
              type="primary"
              onClick={() => {
                setOpen(true);
              }}
            >
              <PlusCircleOutlined />
              新增标签
            </Button>,
          ];
        }}
        columns={columns({ edit, del, enumList: state?.enumList, hot, sort })}
        // bordered
      />
      <BetaSchemaForm<DataItem>
        title={!editValues?.id ? '新增标签' : '编辑标签'}
        formRef={formRef}
        width={600}
        open={open}
        onOpenChange={(b) => {
          !b && closeForm(b);
        }}
        layoutType={'ModalForm'}
        labelCol={{ span: 6 }}
        wrapperCol={{ span: 14 }}
        // grid={true}
        layout="horizontal"
        onFinish={submit}
        columns={formConfig(state?.enumList)}
        loading={BookContentLabelEdit?.loading || BookContentLabelAdd?.loading}
      />
    </PageContainer>
  );
};
export default Page;
