import { api } from '@/services/api';
import { request } from '@umijs/max';

/**
 * 小说修改
 * @param data
 * @returns
 */
export async function apiBookContentLongBookInfoEdit(params: any) {
  let { id, ...data } = params;
  return request(api + `/bookContent/admin/longBookInfo/${id}`, {
    method: 'PUT',
    data,
  });
}
/**
 * 小说新增
 * 
 * @param   "workDirection" 作品方向;0-男频 1-女频
  @param "categoryId" 类别ID
 @param "labelIds" 标签
 @param "picUrl" 封面地址，多个用,拼接
 @param "bookName" 小说名
 @param "authorId" 作者ID
  @param"bookDesc" 书籍描述
 @param "source" 来源（UPLOAD：管理员上传、CREATOR：创作者）
 @param "bookStatus" 书籍状态;0-连载中 1-已完结
 @param "shelveStatus" 上下架状态;0-上架 1-下架
@param  "vipFree" vip 是否免费阅读;0-否，1是
  @param"paymentType" 付费类型：0-免费 1-按千字收费 2-整本收费
@param  "paymentMoney" 付费金额（分）
 */
export async function apiBookContentLongBookInfoAdd(data: any) {
  return request(api + '/bookContent/admin/longBookInfo', {
    method: 'POST',
    data,
  });
}
/**
 * 小说批量上下架
 * @param data
 * @returns
 */
export async function apiBookContentLongBookInfoBatch(data: any) {
  let { shelve, ids } = data;
  return request(api + `/bookContent/admin/longBookInfo/shelve/batch?shelve=${shelve}`, {
    method: 'POST',
    data: ids,
  });
}
/**
 * 小说删除
 * @param data
 * @returns
 */
export async function apiBookContentLongBookInfoDel(id: any) {
  return request(api + `/bookContent/admin/longBookInfo/remove/one/${id}`, {
    method: 'DELETE',
  });
}
/**
 * 小说批量删除
 * @param data
 * @returns
 */
export async function apiBookContentLongBookInfoDels(params: any[]) {
  return request(api + `/bookContent/admin/longBookInfo/remove/batch`, {
    method: 'DELETE',
    data: params,
  });
}
/**
 * 小说列表
 * @param workDirection 频道
 * @param categoryId 分类ID
 * @param labelId 标签ID
 * @param bookName 书籍名称
 * @param authorName 作者名称
 * @param startWordCount 最少字数
 * @param endWordCount 最大字数
 * @param bookStatus 书籍状态;0-连载中 1-已完结
 * @param shelveStatus 上下架状态;0-上架 1-下架
 * @param paymentType  付费类型：0-免费 1-按千字收费 2-整本收费
 * @param vipFree vip 是否免费阅读;0-否 1是
 * @returns
 */
export async function apiBookContentLongBookInfoList(params: any) {
  return request(api + `/bookContent/admin/longBookInfo/list`, {
    method: 'GET',
    params,
  });
}

// =================================章节===========================
/**
 * 小说章节列表
 * @param bookId
 * @param sort
 * @param isPayment
 * */
export async function apiLongBookParagraphList(params: any) {
  return request(api + `/bookContent/admin/longBookChapter/list`, {
    method: 'GET',
    params,
  });
}
/**
 * 小说章节内容
 * @param bookId
 * @param sort
 * @param isPayment
 * */
export async function apiLongBookParagraph(params:any) {
  let {chapterNo,bookId} = params
  return request(api + `/bookContent/admin/longBookChapter/one/${bookId}`, {
    method: 'GET',
    params:{chapterNo}
  });
}

/**
 * 章节新增
 *
 * @param   bookId 小说id
 * @param   paragraphNo 章节号
 * @param   paragraphNo 小说章节内容
 * @param   beginPayment 是否是开始收费章节
 */
export async function apiLongBookParagraphAdd(data: any) {
  return request(api + '/bookContent/admin/longBookChapter', {
    method: 'POST',
    data,
  });
}
/**
 * 章节修改
 * @param id 章节ID
 * @param   bookId 小说id
 * @param   paragraphNo 章节号
 * @param   paragraphNo 小说章节内容
 * @param   beginPayment 是否是开始收费章节
 */
export async function apiLongBookParagraphEdit(params: any) {
  let { id, ...data } = params;
  return request(api + `/bookContent/admin/longBookChapter/${id}`, {
    method: 'PUT',
    data,
  });
}

/**
 * 章节删除
 * @param id  章节ID
 */
export async function apiLongBookParagraphDel(id: any) {
  return request(api + `/bookContent/admin/longBookChapter/remove/one/${id}`, {
    method: 'DELETE',
  });
}

/**上传小说
 * @param bookId
 * @param file
 */
export async function apiLongBookUploadLongBook(data: any) {
  return request(api + '/bookContent/admin/longBookInfo/uploadLongBook', {
    method: 'POST',
    data,
  });
}
/**确认并提交上传的小说信息
 * @param fileUrl
 * @param bookId
 * @param chapterInfos
 */
export async function apiLongBookConfirmUploadLongBook(data: any) {
  return request(api + '/bookContent/admin/longBookInfo/confirmUploadLongBook', {
    method: 'POST',
    data,
  });
}
